Summary:	A next generation Network and traffic analyzer
Name:		ntopng
Version:	2.4
Release:	%mkrel 1
License:	GPLv3
Group:		Monitoring
URL:		http://www.ntop.org
Source0:	https://github.com/ntop/ntopng/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	ntopng.conf
Source2:	ntopng.service
Source3:	ntopng.sysconfig
Source4:	ntopng.tmpfiles.d
Patch0:		ntopng-2.4-ntop-running-user.patch
Patch1:		ntopng-2.4-pidfile.patch
Patch2:		ntopng-2.4-use-system-ndpi.patch
Patch3:		ntopng-2.4-small-fix.patch
BuildRequires:	clang
BuildRequires:	clang-devel
BuildRequires:	pango-devel
BuildRequires:	png-devel
BuildRequires:	cairo-devel
BuildRequires:	GeoIP-devel
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	hiredis-devel
BuildRequires:	json-c-devel
BuildRequires:	libpcap-devel
BuildRequires:	libtool
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	lua-devel
BuildRequires:	luajit-devel
BuildRequires:	openssl-devel
BuildRequires:	pkgconfig
BuildRequires:	pkgconfig(libndpi) >= 1.8
BuildRequires:	redis >= 4.0.7
BuildRequires:	rrdtool-devel
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	wget
BuildRequires:	zeromq-devel >= 3.2.4
BuildRequires:	zlib-devel
BuildRequires:	curl-devel
BuildRequires:	mariadb-devel
BuildRequires:	netfilter_queue-devel
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Requires:	tcp_wrappers
Requires:	rrdtool
Requires:	geoip
Requires:	redis >= 4.0.7
Requires:	openssl-devel
Obsoletes:	ntop < 5.0.1-11

%description
ntopng is the next generation version of the original ntop.
It is a network packet traffic probe and collector that renders
network usage graphically, similar to what the popular top Unix
command does. It is based on libpcap and it has been written in a
portable way in order to virtually run on every Unix platform and on
Windows as well.

ntopng is easy to use and suitable for monitoring enterprise network
environments. A web browser is used to navigate through ntopng's
rendered web pages for viewing current traffic information and/or to
get a data dump of the collected network network status and statistics.
In the latter case, ntopng can be seen as a simple RMON-like agent with
an embedded web interface.

ntopng feature highlights:

* An intuitive web interface sporting numerous visuals and monitoring graphs.
* Show network traffic and IPv4/IPv6 active hosts.
* Analyse IP traffic and sort it according to the source/destination.
* Limited configuration and administration via the web interface.
* Reduced CPU and memory usage (this varies according to network size and
  traffic).
* Collection of a large number of hosts and network statistic values.
* Discover application protocols by leveraging nDPI (i.e., ntop’s Deep Packet
  Inspection Library).
* Report IP protocol usage sorted by protocol type.

%prep
%setup -q
%autopatch -p1

%build
export CC=clang
export CXX=clang++

sh ./autogen.sh --noconfig

%serverbuild

%configure2_5x \
    --bindir=%{_sbindir} \
    --localstatedir=/var/lib

%make_build
#__make

%install

install -d %{buildroot}%{_datadir}/ntopng
install -d %{buildroot}%{_mandir}/man8
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_sysconfdir}/%{name}
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -d %{buildroot}%{_unitdir}

install -m0755 ntopng %{buildroot}%{_sbindir}
install -m0644 ntopng.8 %{buildroot}%{_mandir}/man8

cp -r httpdocs %{buildroot}%{_datadir}/%{name}
cp -r scripts %{buildroot}%{_datadir}/%{name}

find %{buildroot}%{_datadir}/%{name} -name "*~"   | xargs rm -f
find %{buildroot}%{_datadir}/%{name} -name ".svn" | xargs rm -rf
find %{buildroot}%{_datadir}/%{name} -name ".git" | xargs rm -rf

install -d %{buildroot}%{_localstatedir}/lib/%{name}/rrd/{flows,graphics,interfaces}

install -m0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

# fix permissions
find %{buildroot}%{_datadir}/%{name}/httpdocs -type f -print0|xargs -0 chmod 644
find %{buildroot}%{_datadir}/%{name}/httpdocs -type d -print0|xargs -0 chmod 755

# dangling symlinks
rm -rf %{buildroot}%{_datadir}/%{name}/httpdocs/geoip
ln -s %{_datadir}/GeoIP %{buildroot}%{_datadir}/%{name}/httpdocs/geoip
ln -s %{_sysconfdir}/pki/tls/private/%{name}.pem %{buildroot}%{_datadir}/%{name}/httpdocs/ssl/%{name}-cert.pem

install -d %{buildroot}%{_localstatedir}/run/%{name}
mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%pre
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /bin/false

%post
%_post_service ntopng
%_create_ssl_certificate ntopng -b
chown ntopng:ntopng %{_sysconfdir}/pki/tls/private/ntopng.pem

%_tmpfilescreate %{_tmpfilesdir}/%{name}

%preun
%_preun_service ntopng

%files
%doc README* doc/UserGuide.* doc/README*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%{_unitdir}/%{name}.service
%{_sbindir}/%{name}
%{_mandir}/man8/%{name}.8.*
%{_datadir}/%{name}/
%{_tmpfilesdir}/%{name}.conf
%attr(0750,ntopng,ntopng) %dir %{_localstatedir}/lib/%{name}
%attr(0755,ntopng,ntopng) %ghost %dir %{_localstatedir}/run/%{name}


%changelog
* Wed Jan 31 2018 kekepower <kekepower> 2.4-1.mga6
+ Revision: 1198234
- Update to version 2.4
- Rediffed patches for the new version
- Added a few extra BR's
- General cleanup in the spec file
- Rebuild against new redis

* Sat May 07 2016 luigiwalser <luigiwalser> 2.0-6.mga6
+ Revision: 1010331
- obsolete ntop

* Sat May 07 2016 daviddavid <daviddavid> 2.0-5.mga6
+ Revision: 1010295
- rebuild for rrdtool 1.6.0

* Sun Mar 06 2016 blino <blino> 2.0-4.mga6
+ Revision: 986401
- rebuild for armv5tl

* Tue Feb 16 2016 umeabot <umeabot> 2.0-3.mga6
+ Revision: 961772
- Mageia 6 Mass Rebuild

* Thu Nov 12 2015 oden <oden> 2.0-2.mga6
+ Revision: 902700
- fix deps

* Wed Nov 11 2015 oden <oden> 2.0-1.mga6
+ Revision: 902556
- fix sloppy paste
- fix non-ghost-in-var-run
- fix rpmlint error
- fix deps (curl-devel)
- 2.0
- rediff patches
- added one patch from debian
- imported package ntopng

